local Addon, private = ...

setfenv(1, private)

-- Private methods
-- ============================================================================

local markupFormat = "<<%s:%s|%s;>>"
local linkFormat = [=[<u><a lua="LibWiki.PushPageFromLink([[%s]], [[%s]], [[%s]])">%s</a></u>]=]
local linkFormatColored = string.format([=[<font color="#%%s">%s</font>]=], linkFormat)

local format = string.format
local gsub = string.gsub
local function formatter(color, origin, sourceModule, module, path, title)
	return format(linkFormatColored, color, origin, #module > 0 and module or sourceModule, path, #title > 0 and title or path)
end

-- Public methods
-- ============================================================================

--[[ Support either

<<:path>> -> Same module, link to "path" page, link name equals "path"
<<:path|title>> -> Same module, link to "path" page, link name equals "title"
<<module:path>> -> Other module, link to "path" page, link name equals "path"
<<module:path|title>> -> Other module, link to "path" page, link name equals "title"
]]
function MakeLinks(style, origin, sourceModule, text)
	return (gsub(text, "<<([^:]*):([^|>]*)|?(.-);?>>", function(...) return formatter(style.a.color, origin, sourceModule, ...) end))
end

function MakeHyperlinkMarkup(module, path, title)
	return string.format(markupFormat, module, path, title or path)
end

function MakeCopyHyperlinkMarkup(text, title)
	return string.format(markupFormat, "#!copy", path, title or path)
end

function MakeHyperlinkHtml(origin, module, path, text)
	return format(linkFormat, origin, module, path, text)
end
