local Addon, private = ...

setfenv(1, private)

-- Private methods
-- ============================================================================

local function layoutIndexColumns(self, style)
	local padding = style.padding
	
	local width = self:GetWidth()
	local columns = math.max(1, math.min(#self.links, math.ceil((width - self.columnWidth) / (self.columnWidth + padding))))
	if(columns == self.columns) then
		return
	end
	local rows = math.ceil(#self.links / columns)
	local rounded = math.ceil((rows - math.floor(rows)) * columns)
	
	local y = padding
	local height = y
	local col = 0
	for i = 1, #self.links do
		local link = self.links[i]
		link:SetPoint("TOPLEFT", self, col / columns, 0, 0, y)
		y = y + link:GetHeight()
		if(i % rows == 0) then
			height = math.max(height, y)
			y = padding
			col = col + 1
		end
	end
	self.columns = columns
	self:SetHeight(height + padding)
end

-- Public methods
-- ============================================================================

Widgets = Widgets or { }

function Widgets.toc(page, style, module, content, html, createFrame)
	local self = createFrame("Frame", "", page)
	self.links = { }
	self.columnWidth = 0
	self.columns = 0
	local owner = tostring(page)

	for i = 1, #content do
		local link = createFrame("Text", "a", self, function(text)
			text:SetFontSize(style.p.fontSize)
			text:SetEffectGlow(style.p.glow)
			text:SetFontColor(ColorFromHtml(style.p.color))
		end)
		if(html) then
			link:SetText(MakeLinks(style, owner, module, content[i]), html)
		else
			link:SetText(content[i], html)
		end
		self.columnWidth = math.max(self.columnWidth, link:GetWidth())
		self.links[#self.links + 1] = link
	end
	
	self:EventAttach(Event.UI.Layout.Size, function()
		if(not page.frozen) then
			layoutIndexColumns(self, style)
		end
	end, "")
	
	return self, self, 0
end
